pyxmpp2.exceptions.ProtocolError

Package pyxmpp2 :: Module exceptions :: Class ProtocolError |
[hide private]

# Class ProtocolError

Raised when there is something wrong with a stanza processed.

When not processed earlier by an application, the exception will be catched by the stanza dispatcher to return XMPP error to the stanza sender, when allowed.

ProtocolErrors handled internally by PyXMPP will be logged via the logging interface. Errors reported to the sender will be logged using "pyxmpp.ProtocolError.reported" channel and the ignored errors using "pyxmpp.ProtocolError.ignored" channel. Both with the "debug" level.

Instance Methods | [hide private]
__init__(self, xmpp_name, message) x.__init__(...) initializes x; see help(type(x)) for signature |
log_reported(self) Log message via the "pyxmpp.ProtocolError.reported" logger. |
log_ignored(self) Log message via the "pyxmpp.ProtocolError.ignored" logger. |
__unicode__(self) |
__repr__(self) repr(x) |
Inherited from `exceptions.StandardError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| logger_reported = `logging.getLogger("pyxmpp.ProtocolError.repo`...``
| logger_ignored = `logging.getLogger("pyxmpp.ProtocolError.ignor`...``

Properties | [hide private]
| xmpp_name XMPP error name which should be reported
| message The error message.
Inherited from `exceptions.BaseException`: `args` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, xmpp_name, message) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __unicode__(self) |
Overrides: exceptions.BaseException.__unicode__

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

Class Variable Details | [hide private]

  ### logger_reported Value:
      logging.getLogger("pyxmpp.ProtocolError.reported")

  ### logger_ignored Value:
      logging.getLogger("pyxmpp.ProtocolError.ignored")

Property Details | [hide private]

### xmpp_name XMPP error name which should be reported Get Method: unreachable.xmpp_name(self) - XMPP error name which should be reported

### message The error message. Get Method: unreachable.message(self) - The error message.